#!/usr/bin/env python
# -*- coding: utf-8 -*-

__title__ = 'fantasylcs'
__version__ = '1.1.2'
__author__ = 'Kody Thach'
__repo__ = 'https://github.com/kodycode/League-of-Legends-Fantasy-API-Wrapper'
__license__ = 'MIT License'

from .league import FantasyLeague
from .season import SeasonData
from .player import PlayerData
from .team import TeamData
